==> igniteui-react-charts-16.6.8.tgz: package/ES5/FinancialLegend_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { LegendBase } from "./LegendBase";
import { LegendBaseView } from "./LegendBaseView";
import { fromEn, delegateCombine, markType } from "igniteui-react-core/ES5/type";
import { FinancialLegendViewManager } from "./FinancialLegendViewManager";
/**
 * @hidden
 */
var FinancialLegend = /** @class */ (function (_super) {
    tslib_1.__extends(FinancialLegend, _super);
    function FinancialLegend() {
        var _this = _super.call(this) || this;
        _this.ab = FinancialLegend.$;
        var a = _this.at;
        a.collectionChanged = delegateCombine(a.collectionChanged, function (a, b) {
            var e_1, _a, e_2, _b;
            if (b.oldItems != null) {
                try {
                    for (var _c = tslib_1.__values(fromEn(b.oldItems)), _d = _c.next(); !_d.done; _d = _c.next()) {
                        var c = _d.value;
                        _this.a9.al(c);
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
            if (b.newItems != null) {
                try {
                    for (var _e = tslib_1.__values(fromEn(b.newItems)), _f = _e.next(); !_f.done; _f = _e.next()) {
                        var d = _f.value;
                        _this.a9.x(d);
                    }
                }
                catch (e_2_1) { e_2 = { error: e_2_1 }; }
                finally {
                    try {
                        if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
                    }
                    finally { if (e_2) throw e_2.error; }
                }
            }
        });
        return _this;
    }
    FinancialLegend.prototype.aj = function () {
        return new FinancialLegendView(this);
    };
    Object.defineProperty(FinancialLegend.prototype, "a9", {
        get: function () {
            return this.ak;
        },
        enumerable: true,
        configurable: true
    });
    FinancialLegend.prototype.addChildInOrder = function (a, b) {
        this.at.add(a);
    };
    FinancialLegend.prototype.get_isFinancial = function () {
        return true;
    };
    FinancialLegend.$t = markType(FinancialLegend, 'FinancialLegend', LegendBase.$);
    return FinancialLegend;
}(LegendBase));
export { FinancialLegend };
/**
 * @hidden
 */
var FinancialLegendView = /** @class */ (function (_super) {
    tslib_1.__extends(FinancialLegendView, _super);
    function FinancialLegendView(a) {
        var _this = _super.call(this, a) || this;
        _this.c = new FinancialLegendViewManager(_this);
        return _this;
    }
    FinancialLegendView.$t = markType(FinancialLegendView, 'FinancialLegendView', LegendBaseView.$);
    return FinancialLegendView;
}(LegendBaseView));
export { FinancialLegendView };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/FinancialLegend_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { LegendBase } from "./LegendBase";
import { LegendBaseView } from "./LegendBaseView";
import { fromEn, delegateCombine, markType } from "igniteui-react-core/ES5/type";
import { FinancialLegendViewManager } from "./FinancialLegendViewManager";
/**
 * @hidden
 */
var FinancialLegend = /** @class */ (function (_super) {
    tslib_1.__extends(FinancialLegend, _super);
    function FinancialLegend() {
        var _this = _super.call(this) || this;
        _this.ab = FinancialLegend.$;
        var a = _this.at;
        a.collectionChanged = delegateCombine(a.collectionChanged, function (a, b) {
            var e_1, _a, e_2, _b;
            if (b.oldItems != null) {
                try {
                    for (var _c = tslib_1.__values(fromEn(b.oldItems)), _d = _c.next(); !_d.done; _d = _c.next()) {
                        var c = _d.value;
                        _this.bb.an(c);
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
            if (b.newItems != null) {
                try {
                    for (var _e = tslib_1.__values(fromEn(b.newItems)), _f = _e.next(); !_f.done; _f = _e.next()) {
                        var d = _f.value;
                        _this.bb.x(d);
                    }
                }
                catch (e_2_1) { e_2 = { error: e_2_1 }; }
                finally {
                    try {
                        if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
                    }
                    finally { if (e_2) throw e_2.error; }
                }
            }
        });
        return _this;
    }
    FinancialLegend.prototype.aj = function () {
        return new FinancialLegendView(this);
    };
    Object.defineProperty(FinancialLegend.prototype, "bb", {
        get: function () {
            return this.ak;
        },
        enumerable: true,
        configurable: true
    });
    FinancialLegend.prototype.addChildInOrder = function (a, b) {
        this.at.add(a);
    };
    FinancialLegend.prototype.get_isFinancial = function () {
        return true;
    };
    FinancialLegend.$t = markType(FinancialLegend, 'FinancialLegend', LegendBase.$);
    return FinancialLegend;
}(LegendBase));
export { FinancialLegend };
/**
 * @hidden
 */
var FinancialLegendView = /** @class */ (function (_super) {
    tslib_1.__extends(FinancialLegendView, _super);
    function FinancialLegendView(a) {
        var _this = _super.call(this, a) || this;
        _this.c = new FinancialLegendViewManager(_this);
        return _this;
    }
    FinancialLegendView.$t = markType(FinancialLegendView, 'FinancialLegendView', LegendBaseView.$);
    return FinancialLegendView;
}(LegendBaseView));
export { FinancialLegendView };
